@@ -299,6 +299,14 @@ class Issue(OgrAbstractClass):
         """
         raise NotImplementedError()
 
+    def add_assignee(self, *assignees: str) -> None:
+        """
+        Assign users to an issue.
+
+        :param assignees: [str]
+        """
+        raise NotImplementedError()
+
 
 class PRStatus(IntEnum):
     open = 1
@@ -307,6 +315,23 @@ class PRStatus(IntEnum):
     all = 4
 
 
+class CommitStatus(Enum):
+    pending = 1
+    success = 2
+    failure = 3
+    error = 4
+    canceled = 5
+    running = 6
+
+
+class MergeCommitStatus(Enum):
+    can_be_merged = 1
+    cannot_be_merged = 2
+    unchecked = 3
+    checking = 4
+    cannot_be_merged_recheck = 5
+
+
 class PullRequest(OgrAbstractClass):
     @deprecate_and_set_removal(
         since="0.9.0",
@@ -396,6 +421,14 @@ class PullRequest(OgrAbstractClass):
     def head_commit(self) -> str:
         raise NotImplementedError
 
+    @property
+    def merge_commit_sha(self) -> str:
+        raise NotImplementedError()
+
+    @property
+    def merge_commit_status(self) -> MergeCommitStatus:
+        raise NotImplementedError()
+
     @property
     def source_project(self) -> "GitProject":
         raise NotImplementedError()
@@ -580,15 +613,6 @@ class PullRequest(OgrAbstractClass):
         raise NotImplementedError()
 
 
-class CommitStatus(Enum):
-    pending = 1
-    success = 2
-    failure = 3
-    error = 4
-    canceled = 5
-    running = 6
-
-
 class CommitFlag(OgrAbstractClass):
     _states: Dict[str, CommitStatus] = dict()
 
@@ -810,6 +834,22 @@ class GitService(OgrAbstractClass):
         """
         raise NotImplementedError()
 
+    def list_projects(
+        self,
+        namespace: str = None,
+        user: str = None,
+        search_pattern: str = None,
+        language: str = None,
+    ) -> List["GitProject"]:
+        """
+        List projects for given criteria
+
+        :param namespace: str
+        :param owner: str
+        :param search_pattern: str
+        """
+        raise NotImplementedError
+
 
 class GitProject(OgrAbstractClass):
     def __init__(self, repo: str, service: GitService, namespace: str) -> None:
@@ -828,6 +868,22 @@ class GitProject(OgrAbstractClass):
     def __str__(self) -> str:
         return f"GitProject(namespace={self.namespace}, repo={self.repo}, service={self.service})"
 
+    @property
+    def description(self) -> str:
+        """
+        Returns:
+            Project description.
+        """
+        raise NotImplementedError()
+
+    @description.setter
+    def description(self, new_description: str) -> None:
+        """
+        Args:
+            new_description: description to set for project.
+        """
+        raise NotImplementedError()
+
     def delete(self) -> None:
         """Delete the project."""
         raise NotImplementedError()
@@ -888,7 +944,7 @@ class GitProject(OgrAbstractClass):
 
     @property
     def default_branch(self) -> str:
-        """ Return default branch (usually 'main' or 'master'). """
+        """Return default branch (usually 'main' or 'master')."""
         raise NotImplementedError()
 
     def get_description(self) -> str:
