@@ -23,11 +23,11 @@ from typing import Optional, Dict, Any
 
 
 class OgrException(Exception):
-    """ Something went wrong during our execution """
+    """Something went wrong during our execution"""
 
 
 class PagureAPIException(OgrException):
-    """ Exception related to Pagure API """
+    """Exception related to Pagure API"""
 
     def __init__(
         self,
@@ -41,7 +41,7 @@ class PagureAPIException(OgrException):
 
 
 class GithubAPIException(OgrException):
-    """ Exception related to Github API """
+    """Exception related to Github API"""
 
     def __init__(self, *args: Any, github_error: Optional[str] = None) -> None:
         super().__init__(*args)
@@ -49,16 +49,12 @@ class GithubAPIException(OgrException):
 
 
 class GitlabAPIException(OgrException):
-    """ Exception related to Gitlab API """
+    """Exception related to Gitlab API"""
 
     def __init__(self, *args: Any, gitlab_error: Optional[str] = None) -> None:
         super().__init__(*args)
         self.gitlab_error = gitlab_error
 
 
-class OurPagureRawRequest(OgrException):
-    """ Mocking Exceptions for pagure raw request """
-
-
 class OperationNotSupported(OgrException):
-    """ Raise when the operation is not supported by the backend. """
+    """Raise when the operation is not supported by the backend."""
