@@ -27,7 +27,7 @@ from github import UnknownObjectException
 from github.Issue import Issue as _GithubIssue
 
 from ogr.abstract import Issue, IssueComment, IssueStatus
-from ogr.exceptions import GithubAPIException
+from ogr.exceptions import GithubAPIException, OperationNotSupported
 from ogr.services import github as ogr_github
 from ogr.services.base import BaseIssue
 from ogr.services.github.comments import GithubIssueComment
@@ -102,14 +102,17 @@ class GithubIssue(BaseIssue):
         labels: Optional[List[str]] = None,
         assignees: Optional[list] = None,
     ) -> "Issue":
+        if private:
+            raise OperationNotSupported("Private issues are not supported by Github")
+
         github_issue = project.github_repo.create_issue(
             title=title, body=body, labels=labels or [], assignees=assignees or []
         )
         return GithubIssue(github_issue, project)
 
     @staticmethod
-    def get(project: "ogr_github.GithubProject", id: int) -> "Issue":
-        issue = project.github_repo.get_issue(number=id)
+    def get(project: "ogr_github.GithubProject", issue_id: int) -> "Issue":
+        issue = project.github_repo.get_issue(number=issue_id)
         return GithubIssue(issue, project)
 
     @staticmethod
@@ -161,3 +164,6 @@ class GithubIssue(BaseIssue):
     def add_label(self, *labels: str) -> None:
         for label in labels:
             self._raw_issue.add_to_labels(label)
+
+    def add_assignee(self, *assignees: str) -> None:
+        self._raw_issue.edit(assignees=list(assignees))
