@@ -20,7 +20,14 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
 
+import datetime
 import logging
+from ogr.services.github.check_run import (
+    GithubCheckRun,
+    GithubCheckRunOutput,
+    GithubCheckRunResult,
+    GithubCheckRunStatus,
+)
 from typing import Optional, Dict, List, Set, Union
 
 import github
@@ -42,7 +49,7 @@ from ogr.abstract import (
     CommitStatus,
     AccessLevel,
 )
-from ogr.exceptions import GithubAPIException
+from ogr.exceptions import GithubAPIException, OperationNotSupported
 from ogr.read_only import if_readonly, GitProjectReadOnly
 from ogr.services import github as ogr_github
 from ogr.services.base import BaseGitProject
@@ -50,7 +57,7 @@ from ogr.services.github.flag import GithubCommitFlag
 from ogr.services.github.issue import GithubIssue
 from ogr.services.github.pull_request import GithubPullRequest
 from ogr.services.github.release import GithubRelease
-from ogr.utils import filter_paths
+from ogr.utils import filter_paths, indirect
 
 logger = logging.getLogger(__name__)
 
@@ -110,6 +117,22 @@ class GithubProject(BaseGitProject):
             and self.read_only == o.read_only
         )
 
+    @property
+    def description(self) -> str:
+        """
+        Returns:
+            Project description.
+        """
+        return self.github_repo.description
+
+    @description.setter
+    def description(self, new_description: str) -> None:
+        """
+        Args:
+            new_description: description to set for project.
+        """
+        self.github_repo.edit(description=new_description)
+
     def _construct_fork_project(self) -> Optional["GithubProject"]:
         gh_user = self.github_instance.get_user()
         user_login = gh_user.login
@@ -206,7 +229,7 @@ class GithubProject(BaseGitProject):
             raise GithubAPIException("User already added")
 
     def request_access(self):
-        raise NotImplementedError("Not possible on GitHub")
+        raise OperationNotSupported("Not possible on GitHub")
 
     def get_fork(self, create: bool = True) -> Optional["GithubProject"]:
         """
@@ -277,6 +300,7 @@ class GithubProject(BaseGitProject):
             collaborators[user.login] = permission
         return collaborators
 
+    @indirect(GithubIssue.get_list)
     def get_issue_list(
         self,
         status: IssueStatus = IssueStatus.open,
@@ -284,13 +308,13 @@ class GithubProject(BaseGitProject):
         assignee: Optional[str] = None,
         labels: Optional[List[str]] = None,
     ) -> List[Issue]:
-        return GithubIssue.get_list(
-            project=self, status=status, author=author, assignee=assignee, labels=labels
-        )
+        pass
 
+    @indirect(GithubIssue.get)
     def get_issue(self, issue_id: int) -> Issue:
-        return GithubIssue.get(project=self, id=issue_id)
+        pass
 
+    @indirect(GithubIssue.create)
     def create_issue(
         self,
         title: str,
@@ -299,20 +323,18 @@ class GithubProject(BaseGitProject):
         labels: Optional[List[str]] = None,
         assignees: Optional[List[str]] = None,
     ) -> Issue:
-        if private:
-            raise NotImplementedError("Private issues are not supported by Github")
-        return GithubIssue.create(
-            project=self, title=title, body=body, labels=labels, assignees=assignees
-        )
+        pass
 
     def delete(self) -> None:
         self.github_repo.delete()
 
+    @indirect(GithubPullRequest.get_list)
     def get_pr_list(self, status: PRStatus = PRStatus.open) -> List[PullRequest]:
-        return GithubPullRequest.get_list(project=self, status=status)
+        pass
 
+    @indirect(GithubPullRequest.get)
     def get_pr(self, pr_id: int) -> PullRequest:
-        return GithubPullRequest.get(project=self, id=pr_id)
+        pass
 
     def get_sha_from_tag(self, tag_name: str) -> str:
         # TODO: This is ugly. Can we do it better?
@@ -330,6 +352,7 @@ class GithubProject(BaseGitProject):
         return None
 
     @if_readonly(return_function=GitProjectReadOnly.create_pr)
+    @indirect(GithubPullRequest.create)
     def create_pr(
         self,
         title: str,
@@ -338,14 +361,7 @@ class GithubProject(BaseGitProject):
         source_branch: str,
         fork_username: str = None,
     ) -> PullRequest:
-        return GithubPullRequest.create(
-            project=self,
-            title=title,
-            body=body,
-            target_branch=target_branch,
-            source_branch=source_branch,
-            fork_username=fork_username,
-        )
+        pass
 
     @if_readonly(
         return_function=GitProjectReadOnly.commit_comment,
@@ -376,6 +392,7 @@ class GithubProject(BaseGitProject):
         return_function=GitProjectReadOnly.set_commit_status,
         log_message="Create a status on a commit",
     )
+    @indirect(GithubCommitFlag.set)
     def set_commit_status(
         self,
         commit: str,
@@ -397,16 +414,9 @@ class GithubProject(BaseGitProject):
             github.GithubException
         :return:
         """
-        return GithubCommitFlag.set(
-            project=self,
-            commit=commit,
-            state=state,
-            target_url=target_url,
-            description=description,
-            context=context,
-            trim=trim,
-        )
+        pass
 
+    @indirect(GithubCommitFlag.get)
     def get_commit_statuses(self, commit: str) -> List[CommitFlag]:
         """
         Get status of the commit.
@@ -414,7 +424,40 @@ class GithubProject(BaseGitProject):
         :param commit: str
         :return: [CommitFlag]
         """
-        return GithubCommitFlag.get(project=self, commit=commit)
+        pass
+
+    @indirect(GithubCheckRun.get)
+    def get_check_run(
+        self,
+        check_run_id: Optional[int] = None,
+        commit_sha: Optional[str] = None,
+    ) -> Optional["GithubCheckRun"]:
+        pass
+
+    @indirect(GithubCheckRun.create)
+    def create_check_run(
+        self,
+        name: str,
+        commit_sha: str,
+        url: Optional[str] = None,
+        external_id: Optional[str] = None,
+        status: GithubCheckRunStatus = GithubCheckRunStatus.queued,
+        started_at: Optional[datetime.datetime] = None,
+        conclusion: Optional[GithubCheckRunResult] = None,
+        completed_at: Optional[datetime.datetime] = None,
+        output: Optional[GithubCheckRunOutput] = None,
+        actions: Optional[List[Dict[str, str]]] = None,
+    ) -> "GithubCheckRun":
+        pass
+
+    @indirect(GithubCheckRun.get_list)
+    def get_check_runs(
+        self,
+        commit_sha: str,
+        name: Optional[str] = None,
+        status: Optional[GithubCheckRunStatus] = None,
+    ) -> List["GithubCheckRun"]:
+        pass
 
     def get_git_urls(self) -> Dict[str, str]:
         return {"git": self.github_repo.clone_url, "ssh": self.github_repo.ssh_url}
@@ -433,7 +476,7 @@ class GithubProject(BaseGitProject):
         )
 
     def change_token(self, new_token: str):
-        raise NotImplementedError
+        raise OperationNotSupported
 
     def get_file_content(self, path: str, ref=None) -> str:
         ref = ref or self.default_branch
@@ -441,8 +484,10 @@ class GithubProject(BaseGitProject):
             return self.github_repo.get_contents(
                 path=path, ref=ref
             ).decoded_content.decode()
-        except UnknownObjectException as ex:
-            raise FileNotFoundError(f"File '{path}' on {ref} not found", ex)
+        except (UnknownObjectException, GithubException) as ex:
+            if ex.status == 404:
+                raise FileNotFoundError(f"File '{path}' on {ref} not found", ex)
+            raise GithubAPIException(ex)
 
     def get_files(
         self, ref: str = None, filter_regex: str = None, recursive: bool = False
