@@ -22,6 +22,7 @@
 
 import datetime
 import logging
+import requests
 from typing import Optional, List, Union
 
 from github import UnknownObjectException
@@ -31,7 +32,7 @@ from github.Repository import Repository as _GithubRepository
 from github.IssueComment import IssueComment as _GithubIssueComment
 from github.PullRequestComment import PullRequestComment as _GithubPullRequestComment
 
-from ogr.abstract import PRComment, PRStatus, PullRequest
+from ogr.abstract import PRComment, PRStatus, PullRequest, MergeCommitStatus
 from ogr.exceptions import GithubAPIException
 from ogr.services import github as ogr_github
 from ogr.services.base import BasePullRequest
@@ -101,6 +102,17 @@ class GithubPullRequest(BasePullRequest):
     def diff_url(self) -> str:
         return f"{self._raw_pr.html_url}/files"
 
+    @property
+    def patch(self) -> bytes:
+        response = requests.get(self._raw_pr.patch_url)
+
+        if not response.ok:
+            raise GithubAPIException(
+                f"Couldn't get patch from {self._raw_pr.patch_url} because {response.reason}."
+            )
+
+        return response.content
+
     @property
     def commits_url(self) -> str:
         return f"{self._raw_pr.html_url}/commits"
@@ -109,6 +121,17 @@ class GithubPullRequest(BasePullRequest):
     def head_commit(self) -> str:
         return self._raw_pr.head.sha
 
+    @property
+    def merge_commit_sha(self) -> str:
+        return self._raw_pr.merge_commit_sha
+
+    @property
+    def merge_commit_status(self) -> MergeCommitStatus:
+        if self._raw_pr.mergeable:
+            return MergeCommitStatus.can_be_merged
+        else:
+            return MergeCommitStatus.cannot_be_merged
+
     @property
     def source_project(self) -> "ogr_github.GithubProject":
         if self._source_project is None:
@@ -167,8 +190,8 @@ class GithubPullRequest(BasePullRequest):
         return forks[0]
 
     @staticmethod
-    def get(project: "ogr_github.GithubProject", id: int) -> "PullRequest":
-        pr = project.github_repo.get_pull(number=id)
+    def get(project: "ogr_github.GithubProject", pr_id: int) -> "PullRequest":
+        pr = project.github_repo.get_pull(number=pr_id)
         return GithubPullRequest(pr, project)
 
     @staticmethod
