@@ -67,7 +67,10 @@ class GitlabIssue(BaseIssue):
 
     @property
     def assignees(self) -> list:
-        return self._raw_issue.assignees
+        try:
+            return self._raw_issue.assignees
+        except AttributeError:
+            return None  # if issue has no assignees, the attribute is not present
 
     @property
     def description(self) -> str:
@@ -102,21 +105,30 @@ class GitlabIssue(BaseIssue):
         labels: Optional[List[str]] = None,
         assignees: Optional[List[str]] = None,
     ) -> "Issue":
+        assignee_ids = []
+        for user in assignees or []:
+            users_list = project.service.gitlab_instance.users.list(username=user)
+
+            if not users_list:
+                raise GitlabAPIException(f"Unable to find '{user}' username")
+
+            assignee_ids.append(str(users_list[0].id))
+
         data = {"title": title, "description": body}
         if labels:
             data["labels"] = ",".join(labels)
         if assignees:
-            data["assignee_ids"] = ",".join(assignees)
+            data["assignee_ids"] = ",".join(assignee_ids)
 
         issue = project.gitlab_repo.issues.create(data, confidential=private)
         return GitlabIssue(issue, project)
 
     @staticmethod
-    def get(project: "ogr_gitlab.GitlabProject", id: int) -> "Issue":
+    def get(project: "ogr_gitlab.GitlabProject", issue_id: int) -> "Issue":
         try:
-            return GitlabIssue(project.gitlab_repo.issues.get(id), project)
+            return GitlabIssue(project.gitlab_repo.issues.get(issue_id), project)
         except gitlab.exceptions.GitlabGetError as ex:
-            raise GitlabAPIException(f"Issue {id} was not found. ", ex)
+            raise GitlabAPIException(f"Issue {issue_id} was not found. ", ex)
 
     @staticmethod
     def get_list(
@@ -162,3 +174,18 @@ class GitlabIssue(BaseIssue):
         for label in labels:
             self._raw_issue.labels.append(label)
         self._raw_issue.save()
+
+    def add_assignee(self, *assignees: str) -> None:
+        assignee_ids = self._raw_issue.__dict__.get("assignee_ids") or []
+        for assignee in assignees:
+            users = self.project.service.gitlab_instance.users.list(  # type: ignore
+                username=assignee
+            )
+            if not users:
+                raise GitlabAPIException(f"Unable to find '{assignee}' username")
+            uid = str(users[0].id)
+            if uid not in assignee_ids:
+                assignee_ids.append(str(users[0].id))
+
+        self._raw_issue.assignee_ids = assignee_ids
+        self._raw_issue.save()
