@@ -1,30 +1,11 @@
-# MIT License
-#
-# Copyright (c) 2018-2019 Red Hat, Inc.
-
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
-#
-# The above copyright notice and this permission notice shall be included in all
-# copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-# SOFTWARE.
+# Copyright Contributors to the Packit project.
+# SPDX-License-Identifier: MIT
 
 import logging
 from typing import List, Optional, Dict, Set, Union
 
 import gitlab
-from gitlab.v4.objects import GitlabGetError, Project as GitlabObjectsProject
+from gitlab.v4.objects import Project as GitlabObjectsProject
 
 from ogr.abstract import (
     PullRequest,
@@ -45,7 +26,7 @@ from ogr.services.gitlab.flag import GitlabCommitFlag
 from ogr.services.gitlab.issue import GitlabIssue
 from ogr.services.gitlab.pull_request import GitlabPullRequest
 from ogr.services.gitlab.release import GitlabRelease
-from ogr.utils import filter_paths
+from ogr.utils import filter_paths, indirect
 
 logger = logging.getLogger(__name__)
 
@@ -128,7 +109,7 @@ class GitlabProject(BaseGitProject):
         try:
             _ = self.gitlab_repo
             return True
-        except GitlabGetError as ex:
+        except gitlab.exceptions.GitlabGetError as ex:
             if "404 Project Not Found" in str(ex):
                 return False
             raise GitlabAPIException from ex
@@ -147,6 +128,23 @@ class GitlabProject(BaseGitProject):
     def get_description(self) -> str:
         return self.gitlab_repo.attributes["description"]
 
+    @property
+    def description(self) -> str:
+        """
+        Returns:
+            Project description.
+        """
+        return self.gitlab_repo.attributes["description"]
+
+    @description.setter
+    def description(self, new_description: str) -> None:
+        """
+        Args:
+            new_description: description to set for project.
+        """
+        self.gitlab_repo.description = new_description
+        self.gitlab_repo.save()
+
     def get_fork(self, create: bool = True) -> Optional["GitlabProject"]:
         """
         Provide GitlabProject instance of a fork of this project.
@@ -263,8 +261,9 @@ class GitlabProject(BaseGitProject):
         except gitlab.exceptions.GitlabCreateError as e:
             raise GitlabAPIException("Unable to request access", e)
 
+    @indirect(GitlabPullRequest.get_list)
     def get_pr_list(self, status: PRStatus = PRStatus.open) -> List["PullRequest"]:
-        return GitlabPullRequest.get_list(project=self, status=status)
+        pass
 
     def get_sha_from_tag(self, tag_name: str) -> str:
         try:
@@ -274,6 +273,7 @@ class GitlabProject(BaseGitProject):
             logger.error(f"Tag {tag_name} was not found.")
             raise GitlabAPIException(f"Tag {tag_name} was not found.", ex)
 
+    @indirect(GitlabPullRequest.create)
     def create_pr(
         self,
         title: str,
@@ -282,14 +282,7 @@ class GitlabProject(BaseGitProject):
         source_branch: str,
         fork_username: str = None,
     ) -> "PullRequest":
-        return GitlabPullRequest.create(
-            project=self,
-            title=title,
-            body=body,
-            target_branch=target_branch,
-            source_branch=source_branch,
-            fork_username=fork_username,
-        )
+        pass
 
     def commit_comment(
         self, commit: str, body: str, filename: str = None, row: int = None
@@ -317,6 +310,7 @@ class GitlabProject(BaseGitProject):
             raw_comment = commit_object.comments.create({"note": body})
         return self._commit_comment_from_gitlab_object(raw_comment, commit)
 
+    @indirect(GitlabCommitFlag.set)
     def set_commit_status(
         self,
         commit: str,
@@ -337,23 +331,16 @@ class GitlabProject(BaseGitProject):
         :param trim: Whether to trim the description to 140 characters
         :return: CommitFlag
         """
-        return GitlabCommitFlag.set(
-            project=self,
-            commit=commit,
-            state=state,
-            target_url=target_url,
-            description=description,
-            context=context,
-            trim=trim,
-        )
+        pass
 
+    @indirect(GitlabCommitFlag.get)
     def get_commit_statuses(self, commit: str) -> List[CommitFlag]:
         """
         Get the statuses of a commit in a project.
         :param commit: The SHA of the commit.
         :return: [CommitFlag]
         """
-        return GitlabCommitFlag.get(project=self, commit=commit)
+        pass
 
     def get_git_urls(self) -> Dict[str, str]:
         return {
@@ -389,7 +376,9 @@ class GitlabProject(BaseGitProject):
             file = self.gitlab_repo.files.get(file_path=path, ref=ref)
             return file.decode().decode()
         except gitlab.exceptions.GitlabGetError as ex:
-            raise FileNotFoundError(f"File '{path}' on {ref} not found", ex)
+            if ex.response_code == 404:
+                raise FileNotFoundError(f"File '{path}' on {ref} not found", ex)
+            raise GitlabAPIException(ex)
 
     def get_files(
         self, ref: str = None, filter_regex: str = None, recursive: bool = False
@@ -414,6 +403,7 @@ class GitlabProject(BaseGitProject):
 
         return paths
 
+    @indirect(GitlabIssue.get_list)
     def get_issue_list(
         self,
         status: IssueStatus = IssueStatus.open,
@@ -421,13 +411,13 @@ class GitlabProject(BaseGitProject):
         assignee: Optional[str] = None,
         labels: Optional[List[str]] = None,
     ) -> List[Issue]:
-        return GitlabIssue.get_list(
-            project=self, status=status, author=author, assignee=assignee, labels=labels
-        )
+        pass
 
+    @indirect(GitlabIssue.get)
     def get_issue(self, issue_id: int) -> Issue:
-        return GitlabIssue.get(project=self, id=issue_id)
+        pass
 
+    @indirect(GitlabIssue.create)
     def create_issue(
         self,
         title: str,
@@ -436,27 +426,11 @@ class GitlabProject(BaseGitProject):
         labels: Optional[List[str]] = None,
         assignees: Optional[List[str]] = None,
     ) -> Issue:
+        pass
 
-        ids = []
-        for user in assignees or []:
-            users_list = self.service.gitlab_instance.users.list(username=user)
-
-            if not users_list:
-                raise GitlabAPIException(f"Unable to find '{user}' username")
-
-            ids.append(str(users_list[0].id))
-
-        return GitlabIssue.create(
-            project=self,
-            title=title,
-            body=body,
-            private=private,
-            labels=labels,
-            assignees=ids,
-        )
-
+    @indirect(GitlabPullRequest.get)
     def get_pr(self, pr_id: int) -> PullRequest:
-        return GitlabPullRequest.get(project=self, id=pr_id)
+        pass
 
     def get_tags(self) -> List["GitTag"]:
         tags = self.gitlab_repo.tags.list()
