@@ -21,11 +21,12 @@
 # SOFTWARE.
 
 import datetime
-from typing import List, Optional
+import requests
+from typing import Dict, List, Optional
 
 from gitlab.v4.objects import MergeRequest as _GitlabMergeRequest
 
-from ogr.abstract import PullRequest, PRComment, PRStatus
+from ogr.abstract import PullRequest, PRComment, PRStatus, MergeCommitStatus
 from ogr.exceptions import GitlabAPIException
 from ogr.services import gitlab as ogr_gitlab
 from ogr.services.base import BasePullRequest
@@ -36,6 +37,13 @@ class GitlabPullRequest(BasePullRequest):
     _raw_pr: _GitlabMergeRequest
     _target_project: "ogr_gitlab.GitlabProject"
     _source_project: "ogr_gitlab.GitlabProject" = None
+    _merge_commit_status: Dict[str, MergeCommitStatus] = {
+        "can_be_merged": MergeCommitStatus.can_be_merged,
+        "cannot_be_merged": MergeCommitStatus.cannot_be_merged,
+        "unchecked": MergeCommitStatus.unchecked,
+        "checking": MergeCommitStatus.checking,
+        "cannot_be_merged_recheck": MergeCommitStatus.cannot_be_merged_recheck,
+    }
 
     @property
     def title(self) -> str:
@@ -99,10 +107,33 @@ class GitlabPullRequest(BasePullRequest):
     def commits_url(self) -> str:
         return f"{self._raw_pr.web_url}/commits"
 
+    @property
+    def patch(self) -> bytes:
+        response = requests.get(f"{self.url}.patch")
+
+        if not response.ok:
+            raise GitlabAPIException(
+                f"Couldn't get patch from {self.url}.patch because {response.reason}."
+            )
+
+        return response.content
+
     @property
     def head_commit(self) -> str:
         return self._raw_pr.sha
 
+    @property
+    def merge_commit_sha(self) -> str:
+        return self._raw_pr.merge_commit_sha
+
+    @property
+    def merge_commit_status(self) -> MergeCommitStatus:
+        status = self._raw_pr.merge_status
+        if status in self._merge_commit_status:
+            return self._merge_commit_status[status]
+        else:
+            raise GitlabAPIException(f"Invalid merge_status {status}")
+
     @property
     def source_project(self) -> "ogr_gitlab.GitlabProject":
         if self._source_project is None:
@@ -191,8 +222,8 @@ class GitlabPullRequest(BasePullRequest):
         return forks[0]
 
     @staticmethod
-    def get(project: "ogr_gitlab.GitlabProject", id: int) -> "PullRequest":
-        mr = project.gitlab_repo.mergerequests.get(id)
+    def get(project: "ogr_gitlab.GitlabProject", pr_id: int) -> "PullRequest":
+        mr = project.gitlab_repo.mergerequests.get(pr_id)
         return GitlabPullRequest(mr, project)
 
     @staticmethod
