@@ -20,8 +20,11 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
 
+from typing import List
+
 from ogr.services import gitlab as ogr_gitlab
 from ogr.services.base import BaseGitUser
+from ogr.exceptions import OperationNotSupported
 
 
 class GitlabUser(BaseGitUser):
@@ -42,3 +45,9 @@ class GitlabUser(BaseGitUser):
 
     def get_email(self) -> str:
         return self._gitlab_user.email
+
+    def get_projects(self) -> List["ogr_gitlab.GitlabProject"]:
+        raise OperationNotSupported
+
+    def get_forks(self) -> List["ogr_gitlab.GitlabProject"]:
+        raise OperationNotSupported
