@@ -37,7 +37,6 @@ from ogr.abstract import (
     AccessLevel,
 )
 from ogr.exceptions import (
-    OurPagureRawRequest,
     PagureAPIException,
     OgrException,
     OperationNotSupported,
@@ -49,7 +48,7 @@ from ogr.services.pagure.flag import PagureCommitFlag
 from ogr.services.pagure.issue import PagureIssue
 from ogr.services.pagure.pull_request import PagurePullRequest
 from ogr.services.pagure.release import PagureRelease
-from ogr.utils import RequestResponse, filter_paths
+from ogr.utils import RequestResponse, filter_paths, indirect
 
 logger = logging.getLogger(__name__)
 
@@ -186,6 +185,22 @@ class PagureProject(BaseGitProject):
     def get_description(self) -> str:
         return self.get_project_info()["description"]
 
+    @property
+    def description(self) -> str:
+        """
+        Returns:
+            Project description.
+        """
+        return self.get_project_info()["description"]
+
+    @description.setter
+    def description(self, new_description: str) -> None:
+        """
+        Args:
+            new_description: description to set for project.
+        """
+        raise OperationNotSupported("Not possible on Pagure")
+
     def get_owners(self) -> List[str]:
         project = self.get_project_info()
         return project["access_users"]["owner"]
@@ -211,8 +226,9 @@ class PagureProject(BaseGitProject):
         return username in self.who_can_merge_pr()
 
     def request_access(self):
-        raise NotImplementedError("Not possible on Pagure")
+        raise OperationNotSupported("Not possible on Pagure")
 
+    @indirect(PagureIssue.get_list)
     def get_issue_list(
         self,
         status: IssueStatus = IssueStatus.open,
@@ -220,16 +236,16 @@ class PagureProject(BaseGitProject):
         assignee: Optional[str] = None,
         labels: Optional[List[str]] = None,
     ) -> List[Issue]:
-        return PagureIssue.get_list(
-            project=self, status=status, author=author, assignee=assignee, labels=labels
-        )
+        pass
 
+    @indirect(PagureIssue.get)
     def get_issue(self, issue_id: int) -> Issue:
-        return PagureIssue.get(project=self, id=issue_id)
+        pass
 
     def delete(self) -> None:
         self._call_project_api_raw("delete", method="POST")
 
+    @indirect(PagureIssue.create)
     def create_issue(
         self,
         title: str,
@@ -238,26 +254,20 @@ class PagureProject(BaseGitProject):
         labels: Optional[List[str]] = None,
         assignees: Optional[List[str]] = None,
     ) -> Issue:
-        return PagureIssue.create(
-            project=self,
-            title=title,
-            body=body,
-            labels=labels,
-            private=private,
-            assignees=assignees,
-        )
+        pass
 
+    @indirect(PagurePullRequest.get_list)
     def get_pr_list(
         self, status: PRStatus = PRStatus.open, assignee=None, author=None
     ) -> List[PullRequest]:
-        return PagurePullRequest.get_list(
-            project=self, status=status, assignee=assignee, author=author
-        )
+        pass
 
+    @indirect(PagurePullRequest.get)
     def get_pr(self, pr_id: int) -> PullRequest:
-        return PagurePullRequest.get(project=self, id=pr_id)
+        pass
 
     @if_readonly(return_function=GitProjectReadOnly.create_pr)
+    @indirect(PagurePullRequest.create)
     def create_pr(
         self,
         title: str,
@@ -266,14 +276,7 @@ class PagureProject(BaseGitProject):
         source_branch: str,
         fork_username: str = None,
     ) -> PullRequest:
-        return PagurePullRequest.create(
-            project=self,
-            title=title,
-            body=body,
-            target_branch=target_branch,
-            source_branch=source_branch,
-            fork_username=fork_username,
-        )
+        pass
 
     @if_readonly(return_function=GitProjectReadOnly.fork_create)
     def fork_create(self) -> "PagureProject":
@@ -342,7 +345,7 @@ class PagureProject(BaseGitProject):
         ]:
             # private repositories are not allowed on generally used pagure instances
             return False
-        raise NotImplementedError(
+        raise OperationNotSupported(
             f"is_private is not implemented for {self.service.instance_url}."
             f"Please open issue in https://github.com/packit/ogr"
         )
@@ -434,15 +437,13 @@ class PagureProject(BaseGitProject):
 
     def get_file_content(self, path: str, ref=None) -> str:
         ref = ref or self.default_branch
-        try:
-            result = self._call_project_api_raw(
-                "raw", ref, "f", path, add_api_endpoint_part=False
-            )
-            if not result or result.reason == "NOT FOUND":
-                raise FileNotFoundError(f"File '{path}' on {ref} not found")
-            return result.content.decode()
-        except OurPagureRawRequest as ex:
-            raise FileNotFoundError(f"Problem with getting file '{path}' on {ref}", ex)
+        result = self._call_project_api_raw(
+            "raw", ref, "f", path, add_api_endpoint_part=False
+        )
+
+        if not result or result.reason == "NOT FOUND":
+            raise FileNotFoundError(f"File '{path}' on {ref} not found")
+        return result.content.decode()
 
     def get_sha_from_tag(self, tag_name: str) -> str:
         tags_dict = self.get_tags_dict()
@@ -457,6 +458,7 @@ class PagureProject(BaseGitProject):
         raise OperationNotSupported("Commit comments are not supported on Pagure.")
 
     @if_readonly(return_function=GitProjectReadOnly.set_commit_status)
+    @indirect(PagureCommitFlag.set)
     def set_commit_status(
         self,
         commit: str,
@@ -468,20 +470,11 @@ class PagureProject(BaseGitProject):
         uid: str = None,
         trim: bool = False,
     ) -> "CommitFlag":
-        return PagureCommitFlag.set(
-            project=self,
-            commit=commit,
-            state=state,
-            target_url=target_url,
-            description=description,
-            context=context,
-            percent=percent,
-            trim=trim,
-            uid=uid,
-        )
+        pass
 
+    @indirect(PagureCommitFlag.get)
     def get_commit_statuses(self, commit: str) -> List[CommitFlag]:
-        return PagureCommitFlag.get(project=self, commit=commit)
+        pass
 
     def get_tags(self) -> List[GitTag]:
         response = self._call_project_api("git", "tags", params={"with_commits": True})
@@ -496,6 +489,12 @@ class PagureProject(BaseGitProject):
         git_tags = self.get_tags()
         return [self._release_from_git_tag(git_tag) for git_tag in git_tags]
 
+    def get_release(self, identifier=None, name=None, tag_name=None) -> PagureRelease:
+        raise OperationNotSupported
+
+    def get_latest_release(self) -> Optional[PagureRelease]:
+        raise OperationNotSupported
+
     def _release_from_git_tag(self, git_tag: GitTag) -> PagureRelease:
         return PagureRelease(
             tag_name=git_tag.name,
