@@ -1,7 +1,10 @@
+# Copyright Contributors to the Packit project.
+# SPDX-License-Identifier: MIT
+
 from requre.online_replacing import record_requests_for_all_methods
 
 from tests.integration.gitlab.base import GitlabTests
-from ogr.abstract import PRStatus, CommitStatus
+from ogr.abstract import PRStatus, CommitStatus, MergeCommitStatus
 
 
 @record_requests_for_all_methods()
@@ -71,10 +74,14 @@ class PullRequests(GitlabTests):
         """
         Create new PR and update pull request ID to this test before this test
         """
-        pull_request_id = 53
+        pull_request_id = 71
         pr_for_merging = self.project.get_pr(pr_id=pull_request_id)
         assert pr_for_merging.status == PRStatus.open
 
+        # WARNING: this produces different PUT calls depending on
+        # the version of python-gitlab (<2.7.0 or >=2.7.0).
+        # Duplicate and manually fix the URL in the requre cassette
+        # in order to work around this.
         merged_pr = pr_for_merging.merge()
         assert merged_pr.status == PRStatus.merged
 
@@ -167,6 +174,21 @@ class PullRequests(GitlabTests):
             == "59b1a9bab5b5198c619270646410867788685c16"
         )
 
+    def test_merge_commit_sha(self):
+        pr1 = self.project.get_pr(1)
+        pr12 = self.project.get_pr(12)
+        pr19 = self.project.get_pr(19)
+        pr79 = self.project.get_pr(79)
+        assert pr1.merge_commit_sha == "101a42bbbe174d04b465d49caf274dc3b4defeca"
+        assert pr1.merge_commit_status == MergeCommitStatus.can_be_merged
+        assert pr12.merge_commit_sha == "f6de56d97ec3ec74cd5194e79175162d9f969195"
+        assert pr12.merge_commit_status == MergeCommitStatus.can_be_merged
+        assert pr19.merge_commit_sha == "b8e18207cfdad954f1b3a96db34d0706b272e6cf"
+        assert pr19.merge_commit_status == MergeCommitStatus.can_be_merged
+        assert pr79.head_commit == "45e3737aea87a9fd14adcf6a42070cb4f8665ada"
+        assert pr79.merge_commit_sha is None
+        assert pr79.merge_commit_status == MergeCommitStatus.cannot_be_merged
+
     def test_source_project_upstream_branch(self):
         pr = self.project.get_pr(23)
         source_project = pr.source_project
@@ -328,3 +350,9 @@ class PullRequests(GitlabTests):
             pr.commits_url
             == "https://gitlab.com/packit-service/ogr-tests/-/merge_requests/3/commits"
         )
+
+    def test_pr_patch(self):
+        pr = self.project.get_pr(3)
+        patch = pr.patch
+        assert isinstance(patch, bytes)
+        assert "\nDate: Wed, 11 Sep 2019 14:50:41 +0200\n" in patch.decode()
