@@ -30,6 +30,10 @@ class GenericCommands(PagureTests):
         description = self.ogr_project.get_description()
         assert description.startswith("Testing repository for python-ogr package")
 
+    def test_description_property(self):
+        description = self.ogr_project.description
+        assert description.startswith("Testing repository for python-ogr package")
+
     def test_branches(self):
         branches = self.ogr_project.get_branches()
         assert branches
@@ -75,7 +79,7 @@ class GenericCommands(PagureTests):
         )
         assert files
         assert len(files) >= 3
-        assert set(("a/b/lib.c", "a/b/main.c", "a/b/some_other_lib.c")).issubset(files)
+        assert {"a/b/lib.c", "a/b/main.c", "a/b/some_other_lib.c"}.issubset(files)
 
     def test_nonexisting_file(self):
         with self.assertRaises(Exception) as _:
